@@ -224,6 +224,14 @@ class AcadosInterface(SolverInterface):
         """
 
         # constraints handling in self.acados_ocp
+        if ocp.nlp[0].x_bounds.type != InterpolationType.CONSTANT_WITH_FIRST_AND_LAST_DIFFERENT:
+            raise NotImplementedError(
+                "ACADOS must declare an InterpolationType.CONSTANT_WITH_FIRST_AND_LAST_DIFFERENT " "for the x_bounds"
+            )
+        if ocp.nlp[0].u_bounds.type != InterpolationType.CONSTANT_WITH_FIRST_AND_LAST_DIFFERENT:
+            raise NotImplementedError(
+                "ACADOS must declare an InterpolationType.CONSTANT_WITH_FIRST_AND_LAST_DIFFERENT " "for the u_bounds"
+            )
         u_min = np.array(ocp.nlp[0].u_bounds.min)
         u_max = np.array(ocp.nlp[0].u_bounds.max)
         x_min = np.array(ocp.nlp[0].x_bounds.min)
@@ -476,6 +484,8 @@ class AcadosInterface(SolverInterface):
         elif self.acados_ocp.cost.cost_type == "NONLINEAR_LS":
             for i in range(ocp.n_phases):
                 for j, J in enumerate(ocp.nlp[i].J):
+                    if not J:
+                        continue
                     if J[0]["objective"].type.get_type() == ObjectiveFunction.LagrangeFunction:
                         self.lagrange_costs = vertcat(self.lagrange_costs, J[0]["val"].reshape((-1, 1)))
                         self.W = linalg.block_diag(self.W, np.diag([J[0]["objective"].weight] * J[0]["val"].numel()))
@@ -555,7 +565,7 @@ class AcadosInterface(SolverInterface):
 
         param_init = []
         for n in range(self.acados_ocp.dims.N):
-            if self.y_ref:
+            if self.y_ref:  # Target
                 self.ocp_solver.cost_set(n, "yref", np.vstack([data[n] for data in self.y_ref])[:, 0])
             # check following line
             # self.ocp_solver.cost_set(n, "W", self.W)
@@ -616,11 +626,14 @@ class AcadosInterface(SolverInterface):
         options: dict
             The dictionary of options
         """
+        if options is None:
+            options = {}
 
         if "acados_dir" in options:
             del options["acados_dir"]
         if "cost_type" in options:
             del options["cost_type"]
+
         if self.ocp_solver is None:
             self.acados_ocp.solver_options.qp_solver = "PARTIAL_CONDENSING_HPIPM"  # FULL_CONDENSING_QPOASES
             self.acados_ocp.solver_options.hessian_approx = "GAUSS_NEWTON"
